@@ -1,10 +1,10 @@
 """
 Tests for `tqdm.contrib.itertools`.
 """
-import itertools
+import itertools as it
 
 from tqdm.contrib.itertools import product
-from .tests_tqdm import pretest_posttest  # NOQA, pylint: disable=unused-import
+
 from .tests_tqdm import StringIO, closing
 
 
@@ -21,8 +21,6 @@ def test_product():
     """Test contrib.itertools.product"""
     with closing(StringIO()) as our_file:
         a = range(9)
-        assert list(product(a, a[::-1], file=our_file)) == \
-            list(itertools.product(a, a[::-1]))
+        assert list(product(a, a[::-1], file=our_file)) == list(it.product(a, a[::-1]))
 
-        assert list(product(a, NoLenIter(a), file=our_file)) == \
-            list(itertools.product(a, NoLenIter(a)))
+        assert list(product(a, NoLenIter(a), file=our_file)) == list(it.product(a, NoLenIter(a)))
